@@ -75,13 +75,7 @@ class DjangoItemTest(unittest.TestCase):
         long_name = 'z' * 300
         i = BasePersonItem(name=long_name)
         self.assertFalse(i.is_valid())
-        self.assertEqual(
-            {
-                'age': [u'This field cannot be null.'],
-                'name': [u'Ensure this value has at most 255 characters (it has 300).']
-            },
-            i.errors)
-
+        self.assertEqual(set(i.errors), set(['age', 'name']))
         i = BasePersonItem(name='John')
         self.assertTrue(i.is_valid(exclude=['age']))
         self.assertEqual({}, i.errors)
