@@ -1,3 +1,4 @@
+from __future__ import print_function
 import time
 import tempfile
 import shutil
@@ -242,9 +243,9 @@ class RFC2616PolicyTest(DefaultStorageTest):
                 assert isinstance(result, Response)
                 return result
         except Exception:
-            print 'Request', request
-            print 'Response', response
-            print 'Result', result
+            print('Request', request)
+            print('Response', response)
+            print('Result', result)
             raise
 
     def test_request_cacheability(self):
